@@ -228,7 +228,7 @@ MWAWVec2i ClarisWksDocument::getDocumentPages()
       std::shared_ptr<ClarisWksStruct::DSET> group = iter.second;
       if (!group || group->m_position != ClarisWksStruct::DSET::P_Main)
         continue;
-      int page=textWidth>0.2 ? int(float(group->getUnionChildBox()[1][0])/textWidth-0.2f)+1 : 1;
+      int page=textWidth>0.2f ? int(float(group->getUnionChildBox()[1][0])/textWidth-0.2f)+1 : 1;
       if (page > numHPages && page < numHPages+10) {
         MWAW_DEBUG_MSG(("ClarisWksGraph::computePositions: increase num page accross to %d\n", page));
         numHPages = page;
@@ -962,7 +962,7 @@ std::shared_ptr<ClarisWksStruct::DSET> ClarisWksDocument::readDSET(bool &complet
   }
 
   long debPos = endPos-N*data0Length;
-  for (int i = 0; i < zone->m_numData; i++) {
+  for (long i = 0; i < zone->m_numData; i++) {
     input->seek(debPos, librevenge::RVNG_SEEK_SET);
     f.str("");
     f << "DSETU-" << i << ":";
@@ -2156,7 +2156,7 @@ bool ClarisWksDocument::readDataLinkList()
   ascFile.addNote(f.str().c_str());
 
   pos=input->tell();
-  for (int i = 0; i < zone.m_numData; i++) {
+  for (long i = 0; i < zone.m_numData; i++) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     f.str("");
     f << "DataLink-" << i << ":";
@@ -2212,7 +2212,7 @@ bool ClarisWksDocument::readDataLinkList()
           f << "##id2=" << id << ",";
       }
       if (type==1)
-        m_state->m_linkIdToDabasePictIdMap[i]=id;
+        m_state->m_linkIdToDabasePictIdMap[int(i)]=id;
     }
     else if (i==0) {
       MWAW_DEBUG_MSG(("ClarisWksStruct::readDataLinkList: find unexpected data size\n"));
@@ -2396,7 +2396,7 @@ bool ClarisWksDocument::readStructCellZone(char const *zoneName, bool hasEntete,
     input->seek(header.m_headerSize, librevenge::RVNG_SEEK_CUR);
   }
   f << "[";
-  for (int i = 0; i < header.m_numData; i++) {
+  for (long i = 0; i < header.m_numData; i++) {
     int dim[2];
     for (int &d: dim) d = static_cast<int>(input->readLong(2));
     // checkme: do we need to invert the coordinate
@@ -2439,13 +2439,13 @@ bool ClarisWksDocument::readZoneA()
   }
   if (header.m_dataSize==4) {
     f << "ptrs=[";
-    for (int i = 0; i < header.m_numData; i++) f << std::hex << input->readULong(4) << std::dec << ",";
+    for (long i = 0; i < header.m_numData; i++) f << std::hex << input->readULong(4) << std::dec << ",";
     f << "],";
   }
   else {
     ascFile.addPos(pos);
     ascFile.addNote(f.str().c_str());
-    for (int i = 0; i < header.m_numData; i++) {
+    for (long i = 0; i < header.m_numData; i++) {
       pos=input->tell();
       f.str("");
       f << "ZoneA-" << i << ":";
@@ -2469,7 +2469,7 @@ bool ClarisWksDocument::readZoneA()
   ascFile.addPos(pos);
   ascFile.addNote("ZoneA-A:");
 
-  for (int i=0; i<2*header.m_numData; ++i) {
+  for (long i=0; i<2*header.m_numData; ++i) {
     pos = input->tell();
     if ((i%2)==0) {
       // the header contains a string: some chart/figure name?
