@@ -427,7 +427,6 @@ bool CricketDrawParser::createZones()
   input->seek(0x200, librevenge::RVNG_SEEK_SET);
   int const decal=vers<=2 ? 39 : 63;
   while (!input->isEnd()) {
-    pos=input->tell();
     if (readShape())
       continue;
     pos=input->tell();
@@ -657,9 +656,9 @@ bool CricketDrawParser::readShape()
     for (int i=0; i<3; ++i) {
       val=static_cast<int>(input->readULong(1));
       totalIntensity+=val;
-      int const(expected[])= {0x64,0x19,0x4b};
+      int const expected[] = {0x64,0x19,0x4b};
       if (val==expected[i]) continue;
-      char const *(wh[])= {"begin","end","borders"};
+      char const *wh[]= {"begin","end","borders"};
       f << wh[i] << "[intensities]=" << val << ",";
     }
     float decal[2];
@@ -798,7 +797,7 @@ bool CricketDrawParser::readShape()
   int const numData=vers<=2 ? 9 : 5;
   for (int i=0; i<numData; ++i) {
     val=static_cast<int>(input->readLong(2));
-    int const(expected[])= {0,0x2d,0x48,0,0,0,0,0,0};
+    int const expected[]= {0,0x2d,0x48,0,0,0,0,0,0};
     if (val!=expected[i])
       f << "g" << i+2 << "=" << val << ",";
   }
@@ -1022,7 +1021,7 @@ bool CricketDrawParser::readShape()
       }
       f << "N=" << (dataSize/8) << ",";
       f << "pts=[";
-      for (int pt=0; pt<(dataSize/8); ++pt) {
+      for (long pt=0; pt<(dataSize/8); ++pt) {
         float coord[2];
         for (auto &c : coord) c=float(input->readLong(4))/65536.f;
         shape.m_vertices.push_back(MWAWVec2f(coord[1],coord[0]));
@@ -1493,7 +1492,7 @@ bool CricketDrawParser::sendBitmap(CricketDrawParserInternal::Shape const &bitma
   if (!bitmap.m_bitmap.valid() || bitmap.m_bitmapRowSize<=0 ||
       8*bitmap.m_bitmapRowSize<dim[0] ||
       dim[0] <= 0 || dim[1] <= 0 ||
-      bitmap.m_bitmapRowSize*dim[1]>bitmap.m_bitmap.length()) {
+      dim[1]>bitmap.m_bitmap.length()/bitmap.m_bitmapRowSize) {
     MWAW_DEBUG_MSG(("CricketDrawParser::sendBitmap: oops, the bitmap dimension seems bad\n"));
     return false;
   }
