@@ -65,6 +65,7 @@ struct Paragraph final : public MWAWParagraph {
     , m_addPageBreak(false)
   {
   }
+  Paragraph &operator=(Paragraph const &)=default;
   //! destructor
   ~Paragraph() final;
   //! operator<<
@@ -178,6 +179,7 @@ struct Token {
     , m_extra("")
   {
   }
+  Token &operator=(Token const &)=default;
   //! destructor
   ~Token()
   {
@@ -265,7 +267,7 @@ struct State {
   long m_footerId;
 };
 
-Section getSection(const State &state, const long id)
+static Section getSection(const State &state, const long id)
 {
   auto it = state.m_sectionList.find(id);
   if (it != state.m_sectionList.end())
