@@ -713,7 +713,7 @@ bool MWAWOLEParser::readCompObj(MWAWInputStreamPtr ip, std::string const &oleNam
       st = f.str();
     }
     else {
-      for (int i = 0; i < sz; i++)
+      for (long i = 0; i < sz; i++)
         st += char(ip->readULong(1));
     }
 
