@@ -111,6 +111,8 @@ struct Zone {
   {
     for (auto &id : m_ids) id = 0;
   }
+  Zone &operator=(Zone const &)=default;
+  Zone(Zone const &)=default;
   //! destructor
   virtual ~Zone() {}
 
@@ -1332,6 +1334,7 @@ bool MsWksGraph::readPictHeader(MsWksGraphInternal::Zone &pict)
     break;
   default:
     f << "#arrow=3,";
+    break;
   case 0:
     break;
   }
@@ -1424,6 +1427,7 @@ bool MsWksGraph::readGradient(MsWksGraph::Style &style)
       break;
     default:
       f << "#subType=" << subType << ",";
+      break;
     case 8: // centered
       break;
     }
@@ -2663,7 +2667,7 @@ bool MsWksGraph::readText(MsWksGraphInternal::TextBox &textBox)
       bool ok = true;
       // ok we try to read the string
       std::string chaine("");
-      for (int i = 0; i < sizeOfData; i++) {
+      for (long i = 0; i < sizeOfData; i++) {
         auto c = static_cast<unsigned char>(input->readULong(1));
         if (c == 0) {
           ok = false;
