@@ -151,6 +151,8 @@ struct Paragraph final : public MWAWParagraph {
     , m_type2(0)
   {
   }
+  Paragraph(Paragraph const &)=default;
+  Paragraph &operator=(Paragraph const &)=default;
   //! destructor
   ~Paragraph() final;
   //! operator<<
@@ -723,7 +725,7 @@ bool MsWrd1Parser::readParagraph(long fPos, MsWrd1ParserInternal::Paragraph &par
       break;
     }
     if (val & 0x10) f << "dontbreak[para],";
-    if (val & 0x10) f << "dontbreak[line],";
+    if (val & 0x20) f << "dontbreak[line],";
     if (val & 0xf)
       f << "#justify=" << std::hex << (val & 0xf) << std::dec << ",";
   }
