@@ -48,10 +48,16 @@ namespace MsWrdTextStylesInternal
 //! Internal: the state of a MsWrdTextStylesInternal
 struct State {
   //! constructor
-  State() : m_version(-1), m_defaultFont(2,12),
-    m_nextStyleMap(), m_fontList(), m_paragraphList(), m_sectionList(),
-    m_textstructParagraphList(),
-    m_styleFontMap(), m_styleParagraphMap()
+  State()
+    : m_version(-1)
+    , m_defaultFont(2,12)
+    , m_nextStyleMap()
+    , m_fontList()
+    , m_paragraphList()
+    , m_sectionList()
+    , m_textstructParagraphList()
+    , m_styleFontMap()
+    , m_styleParagraphMap()
   {
   }
   //! the file version
@@ -86,9 +92,11 @@ struct State {
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-MsWrdTextStyles::MsWrdTextStyles(MsWrdText &textParser) :
-  m_parserState(textParser.getParserState()), m_state(new MsWrdTextStylesInternal::State),
-  m_mainParser(textParser.m_mainParser), m_textParser(&textParser)
+MsWrdTextStyles::MsWrdTextStyles(MsWrdText &textParser)
+  : m_parserState(textParser.getParserState())
+  , m_state(new MsWrdTextStylesInternal::State)
+  , m_mainParser(textParser.m_mainParser)
+  , m_textParser(&textParser)
 {
 }
 
@@ -117,7 +125,7 @@ bool MsWrdTextStyles::readFont(MsWrdStruct::Font &font, MsWrdTextStyles::ZoneTyp
 
   MWAWInputStreamPtr &input= m_parserState->m_input;
   long pos = input->tell();
-  int sz = static_cast<int>(input->readULong(1));
+  auto sz = static_cast<int>(input->readULong(1));
   if (sz > 20 || sz == 3) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     return false;
@@ -125,7 +133,7 @@ bool MsWrdTextStyles::readFont(MsWrdStruct::Font &font, MsWrdTextStyles::ZoneTyp
 
   if (sz == 0) return true;
 
-  int flag = static_cast<int>(input->readULong(1));
+  auto flag = static_cast<int>(input->readULong(1));
   uint32_t flags = font.m_font->flags();
   if (flag&0x80) flags ^= MWAWFont::boldBit;
   if (flag&0x40) flags ^= MWAWFont::italicBit;
@@ -147,7 +155,7 @@ bool MsWrdTextStyles::readFont(MsWrdStruct::Font &font, MsWrdTextStyles::ZoneTyp
   if (sz >= 2) what = static_cast<int>(input->readULong(1));
 
   if (sz >= 4) {
-    int fId = static_cast<int>(input->readULong(2));
+    auto fId = static_cast<int>(input->readULong(2));
     if (fId) {
       if (mainZone && (what & 0x50)==0) f << "#fId,";
       font.m_font->setId(fId);
@@ -168,7 +176,7 @@ bool MsWrdTextStyles::readFont(MsWrdStruct::Font &font, MsWrdTextStyles::ZoneTyp
   }
 
   if (sz >= 6) {
-    int decal = static_cast<int>(input->readLong(1)); // unit point
+    auto decal = static_cast<int>(input->readLong(1)); // unit point
     if (decal) {
       if (what & 0x2)
         font.m_font->set(MWAWFont::Script(float(decal)/2.f, librevenge::RVNG_POINT));
@@ -178,7 +186,7 @@ bool MsWrdTextStyles::readFont(MsWrdStruct::Font &font, MsWrdTextStyles::ZoneTyp
     what &= 0xFD;
   }
   if (sz >= 7) {
-    int decal = static_cast<int>(input->readLong(1)); // unit point > 0 -> expand < 0: condensed
+    auto decal = static_cast<int>(input->readLong(1)); // unit point > 0 -> expand < 0: condensed
     if (decal) {
       if ((what & 0x1) == 0) f << "#hDecal=" << decal <<",";
       else font.m_font->setDeltaLetterSpacing(float(decal)/16.0f);
@@ -187,7 +195,7 @@ bool MsWrdTextStyles::readFont(MsWrdStruct::Font &font, MsWrdTextStyles::ZoneTyp
   }
 
   if (sz >= 8) {
-    int val = static_cast<int>(input->readULong(1));
+    auto val = static_cast<int>(input->readULong(1));
     if (val & 0xF0) {
       if (what & 0x20) {
         MWAWColor col;
@@ -202,7 +210,7 @@ bool MsWrdTextStyles::readFont(MsWrdStruct::Font &font, MsWrdTextStyles::ZoneTyp
     what &= 0xDF;
 
     if (val && (what & 0x4)) {
-      MWAWFont::Line::Style style=MWAWFont::Line::Simple;
+      auto style=MWAWFont::Line::Simple;
       switch ((val>>1)&0x7) {
       case 4:
         style=MWAWFont::Line::Dot;
@@ -250,7 +258,7 @@ bool MsWrdTextStyles::readFont(MsWrdStruct::Font &font, MsWrdTextStyles::ZoneTyp
 
   bool ok = false;
   if (mainZone && sz >= 10 && sz <= 12) {
-    int wh = static_cast<int>(input->readULong(1));
+    auto wh = static_cast<int>(input->readULong(1));
     long pictPos = 0;
     for (int i = 10; i < 13; i++) {
       pictPos <<= 8;
@@ -267,7 +275,7 @@ bool MsWrdTextStyles::readFont(MsWrdStruct::Font &font, MsWrdTextStyles::ZoneTyp
       input->seek(pos+1+8, librevenge::RVNG_SEEK_SET);
   }
   if (!ok && sz >= 9) {
-    int wh = static_cast<int>(input->readLong(1));
+    auto wh = static_cast<int>(input->readLong(1));
     switch (wh) {
     case -1:
       ok = true;
@@ -295,7 +303,7 @@ bool MsWrdTextStyles::readFont(MsWrdStruct::Font &font, MsWrdTextStyles::ZoneTyp
 
 bool MsWrdTextStyles::getFont(ZoneType type, int id, MsWrdStruct::Font &font)
 {
-  MsWrdStruct::Font *fFont = 0;
+  MsWrdStruct::Font *fFont = nullptr;
   switch (type) {
   case TextZone:
     if (id < 0 || id >= int(m_state->m_fontList.size()))
@@ -394,7 +402,6 @@ bool MsWrdTextStyles::readParagraph(MsWrdStruct::Paragraph &para, int dataSz)
   if (!input->checkPosition(endPos)) return false;
 
   int const vers = version();
-  libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
   int numFont=0;
   while (long(input->tell()) < endPos) {
@@ -578,6 +585,7 @@ bool MsWrdTextStyles::readParagraph(MsWrdStruct::Paragraph &para, int dataSz)
       MWAW_DEBUG_MSG(("MsWrdTextStyles::readParagraph: can not read end of paragraph\n"));
       first = false;
     }
+    libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
     ascFile.addDelimiter(input->tell(),'|');
     f << "####";
     input->seek(endPos, librevenge::RVNG_SEEK_SET);
@@ -603,15 +611,15 @@ bool MsWrdTextStyles::readPLCList(MsWrdEntry &entry)
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
   f << entry.type() << ":";
-  int N=int(entry.length()/6);
+  auto N=int(entry.length()/6);
   std::vector<long> textPos; // limit of the text in the file
   textPos.resize(size_t(N)+1);
-  for (int i = 0; i <= N; i++) textPos[size_t(i)] = long(input->readULong(4));
+  for (auto &tPos : textPos) tPos = long(input->readULong(4));
   int const expectedSize = (version() <= 3) ? 0x80 : 0x200;
   for (int i = 0; i < N; i++) {
     if (!input->checkPosition(textPos[size_t(i)])) f << "#";
 
-    long defPos = long(input->readULong(2));
+    auto defPos = long(input->readULong(2));
     f << std::hex << "[filePos?=" << textPos[size_t(i)] << ",dPos=" << defPos << std::dec << ",";
     f << "],";
 
@@ -652,8 +660,8 @@ bool MsWrdTextStyles::readPLC(MsWrdEntry &entry, int type, MWAWVec2<long> const
   }
   MWAWInputStreamPtr &input= m_parserState->m_input;
   input->seek(entry.end()-1, librevenge::RVNG_SEEK_SET);
-  int N=static_cast<int>(input->readULong(1));
-  if (5*(N+1) > entry.length()) {
+  auto N=static_cast<int>(input->readULong(1));
+  if (N==0 || 5*(N+1) > entry.length()) {
     MWAW_DEBUG_MSG(("MsWrdTextStyles::readPLC: the number of plc seems odd\n"));
     return false;
   }
@@ -667,8 +675,7 @@ bool MsWrdTextStyles::readPLC(MsWrdEntry &entry, int type, MWAWVec2<long> const
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   std::vector<long> filePos;
   filePos.resize(size_t(N)+1);
-  for (int i = 0; i <= N; i++)
-    filePos[size_t(i)] = long(input->readULong(4));
+  for (auto &fPos : filePos) fPos = long(input->readULong(4));
   if (filePos[0] != fLimit[0]) {
     MWAW_DEBUG_MSG(("MsWrdTextStyles::readPLC: bad first limit\n"));
     return false;
@@ -678,8 +685,8 @@ bool MsWrdTextStyles::readPLC(MsWrdEntry &entry, int type, MWAWVec2<long> const
   decal.resize(size_t(N));
   size_t numData = type == 0 ? m_state->m_fontList.size() :
                    m_state->m_paragraphList.size();
-  MsWrdText::PLC::Type plcType = type == 0 ? MsWrdText::PLC::Font : MsWrdText::PLC::Paragraph;
-  std::multimap<long, MsWrdText::PLC> &plcMap = m_textParser->getFilePLCMap();
+  auto plcType = type == 0 ? MsWrdText::PLC::Font : MsWrdText::PLC::Paragraph;
+  auto &plcMap = m_textParser->getFilePLCMap();
 
   for (size_t i = 0; i < size_t(N); i++) {
     decal[i] = static_cast<int>(input->readULong(1));
@@ -713,7 +720,7 @@ bool MsWrdTextStyles::readPLC(MsWrdEntry &entry, int type, MWAWVec2<long> const
           f2 << "P" << id << ":";
 
           input->seek(dataPos, librevenge::RVNG_SEEK_SET);
-          int sz = static_cast<int>(input->readLong(1));
+          auto sz = static_cast<int>(input->readLong(1));
           long endPos;
           if (vers <= 3) {
             sz++;
@@ -726,7 +733,7 @@ bool MsWrdTextStyles::readPLC(MsWrdEntry &entry, int type, MWAWVec2<long> const
             f2 << "#";
           }
           else {
-            int stId = static_cast<int>(input->readLong(1));
+            auto stId = static_cast<int>(input->readLong(1));
             if (m_state->m_styleParagraphMap.find(stId)==m_state->m_styleParagraphMap.end()) {
               MWAW_DEBUG_MSG(("MsWrdTextStyles::readPLC: can not find parent paragraph\n"));
               f2 << "#";
@@ -743,7 +750,7 @@ bool MsWrdTextStyles::readPLC(MsWrdEntry &entry, int type, MWAWVec2<long> const
               // ie. if (para.m_info->isEmpty()&&stId==0)
             }
             else {   // always 0 ?
-              int val = static_cast<int>(input->readLong(2));
+              auto val = static_cast<int>(input->readLong(2));
               if (val) f << "g0=" << val << ",";
             }
             if (sz >= 4) {
@@ -810,7 +817,7 @@ bool MsWrdTextStyles::readTextStructList(MsWrdEntry &entry)
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
-  int type = static_cast<int>(input->readLong(1));
+  auto type = static_cast<int>(input->readLong(1));
   if (type != 1 && type != 2) {
     MWAW_DEBUG_MSG(("MsWrdTextStyles::readTextStructList: find odd type %d\n", type));
     return false;
@@ -819,7 +826,7 @@ bool MsWrdTextStyles::readTextStructList(MsWrdEntry &entry)
   int num = 0;
   while (type == 1) {
     /* probably a paragraph definition. Fixme: create a function */
-    int length = static_cast<int>(input->readULong(2));
+    auto length = static_cast<int>(input->readULong(2));
     long endPos = pos+3+length;
     if (endPos > entry.end()) {
       ascFile.addPos(pos);
@@ -861,7 +868,7 @@ int MsWrdTextStyles::readPropertyModifier(bool &complex, std::string &extra)
 {
   MWAWInputStreamPtr &input= m_parserState->m_input;
   long pos = input->tell();
-  int c = static_cast<int>(input->readULong(1));
+  auto c = static_cast<int>(input->readULong(1));
   complex = false;
   if (c&0x80) { // complex data, let get the id
     complex=true;
@@ -956,12 +963,12 @@ bool MsWrdTextStyles::readSection(MsWrdEntry &entry, std::vector<long> &cLimits)
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
   f << "Section:";
-  size_t N=size_t(entry.length()/10);
+  auto N=size_t(entry.length()/10);
   cLimits.resize(N+1);
-  for (size_t i = 0; i <= N; i++) cLimits[i] = long(input->readULong(4));
+  for (auto &limit : cLimits) limit = long(input->readULong(4));
 
   MsWrdText::PLC plc(MsWrdText::PLC::Section);
-  std::multimap<long, MsWrdText::PLC> &plcMap = m_textParser->getTextPLCMap();
+  auto &plcMap = m_textParser->getTextPLCMap();
   long textLength = m_textParser->getMainTextLength();
   for (size_t i = 0; i < N; i++) {
     MsWrdStruct::Section sec;
@@ -1007,7 +1014,7 @@ bool MsWrdTextStyles::readSection(MsWrdStruct::Section &sec, long debPos)
   input->seek(debPos, librevenge::RVNG_SEEK_SET);
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
-  int sz = static_cast<int>(input->readULong(1));
+  auto sz = static_cast<int>(input->readULong(1));
   long endPos = debPos+sz+1;
   if (sz < 1 || sz >= 255) {
     MWAW_DEBUG_MSG(("MsWrdTextStyles::readSection: data section size seems bad...\n"));
@@ -1070,7 +1077,7 @@ bool MsWrdTextStyles::sendSection(int id, int textStructId)
     MWAW_DEBUG_MSG(("MsWrdTextStyles::sendText: can not find new section\n"));
     return false;
   }
-  MsWrdStruct::Section section=m_state->m_sectionList[size_t(id)];
+  auto section=m_state->m_sectionList[size_t(id)];
   MsWrdStruct::Paragraph para(version());
   if (textStructId >= 0 &&
       getParagraph(MsWrdTextStyles::TextStructZone, textStructId, para) &&
@@ -1108,7 +1115,7 @@ bool MsWrdTextStyles::readStyles(MsWrdEntry &entry)
   MWAWInputStreamPtr &input= m_parserState->m_input;
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << entry << ":";
-  int N = static_cast<int>(input->readLong(2));
+  auto N = static_cast<int>(input->readLong(2));
   if (N) f << "N?=" << N;
   ascFile.addPos(pos);
   ascFile.addNote(f.str().c_str());
@@ -1118,7 +1125,7 @@ bool MsWrdTextStyles::readStyles(MsWrdEntry &entry)
   int overOk[3]= {0,30,100}; // name, font, paragraph
   for (int st = 0; st < 3; st++) {
     debPos[st] = input->tell();
-    int dataSz = static_cast<int>(input->readULong(2));
+    auto dataSz = static_cast<int>(input->readULong(2));
     long endPos = debPos[st]+dataSz;
     if (dataSz < 2+N || endPos > entry.end()+overOk[st]) {
       ascFile.addPos(pos);
@@ -1155,7 +1162,7 @@ bool MsWrdTextStyles::readStyles(MsWrdEntry &entry)
   if (int(orig.size()) < N+N1)
     orig.resize(size_t(N+N1), -1000);
   if (int(order.size()) < N+N1) {
-    for (int i = int(order.size()); i < N+N1; i++)
+    for (auto i = int(order.size()); i < N+N1; i++)
       order.push_back(i);
   }
   zone.setBegin(debPos[1]);
@@ -1178,7 +1185,7 @@ bool MsWrdTextStyles::readStylesNames(MsWrdEntry const &zone, int N, int &Nnamed
   f << "Styles(names):";
   int actN=0;
   while (long(input->tell()) < zone.end()) {
-    int sz = static_cast<int>(input->readULong(1));
+    auto sz = static_cast<int>(input->readULong(1));
     if (sz == 0) {
       f << "*";
       actN++;
@@ -1252,8 +1259,7 @@ bool MsWrdTextStyles::readStylesFont
     }
   }
 
-  for (size_t i = 0; i < order.size(); i++) {
-    int id = order[i];
+  for (auto id : order) {
     if (id < 0 || id >= int(numElt)) continue;
     int prevId = previous[size_t(id)];
     MsWrdStruct::Font font;
@@ -1314,8 +1320,7 @@ bool MsWrdTextStyles::readStylesParagraph(MsWrdEntry &zone, int N, std::vector<i
       ascFile.addNote(f.str().c_str());
     }
   }
-  for (size_t i = 0; i < order.size(); i++) {
-    int id = order[i];
+  for (auto id : order) {
     if (id < 0 || id >= int(numElt)) continue;
     int prevId = previous[size_t(id)];
     MsWrdStruct::Paragraph para(vers);
@@ -1333,12 +1338,12 @@ bool MsWrdTextStyles::readStylesParagraph(MsWrdEntry &zone, int N, std::vector<i
       }
       else {
         input->seek(debPos[size_t(id)]+1, librevenge::RVNG_SEEK_SET);
-        int pId = static_cast<int>(input->readLong(1));
+        auto pId = static_cast<int>(input->readLong(1));
         if (id >= N && pId != id-N) {
           MWAW_DEBUG_MSG(("MsWrdTextStyles::readStylesParagraph: zone(paragraph) the id seems bad...\n"));
           f << "#id=" << pId << ",";
         }
-        int val = static_cast<int>(input->readLong(2)); // always 0?
+        auto val = static_cast<int>(input->readLong(2)); // always 0?
         if (val) f << "g0=" << val << ",";
 
         if (vers > 3) {
@@ -1372,7 +1377,7 @@ bool MsWrdTextStyles::readStylesHierarchy(MsWrdEntry &entry, int N, std::vector<
   libmwaw::DebugStream f;
   f << "Styles(hierarchy):";
 
-  int N2 = static_cast<int>(input->readULong(2));
+  auto N2 = static_cast<int>(input->readULong(2));
   if (N2 < N) {
     MWAW_DEBUG_MSG(("MsWrdTextStyles::readStylesHierarchy: N seems too small...\n"));
     f << "#N=" << N2 << ",";
@@ -1391,8 +1396,8 @@ bool MsWrdTextStyles::readStylesHierarchy(MsWrdEntry &entry, int N, std::vector<
   orig.resize(0);
   orig.resize(size_t(N2), -1000);
   for (int i = 0; i < N2; i++) {
-    int v0 = static_cast<int>(input->readLong(1)); // often 0 or i-N
-    int v1 = static_cast<int>(input->readLong(1));
+    auto v0 = static_cast<int>(input->readLong(1)); // often 0 or i-N
+    auto v1 = static_cast<int>(input->readLong(1));
     f << "prev(sP"<< i-N << ")";
     if (v1 == -34) {
     }
@@ -1435,13 +1440,13 @@ std::vector<int> MsWrdTextStyles::orderStyles(std::vector<int> const &previous)
   std::vector<int> order, numChild;
   size_t N = previous.size();
   numChild.resize(N, 0);
-  for (size_t i = 0; i < N; i++) {
-    if (previous[i] == -1000) continue;
-    if (previous[i] < 0 || previous[i] >= int(N)) {
-      MWAW_DEBUG_MSG(("MsWrdTextStyles::orderStyles: find a bad previous %d\n", previous[i]));
+  for (auto id : previous) {
+    if (id == -1000) continue;
+    if (id < 0 || id >= int(N)) {
+      MWAW_DEBUG_MSG(("MsWrdTextStyles::orderStyles: find a bad previous %d\n", id));
       continue;
     }
-    numChild[size_t(previous[i])]++;
+    numChild[size_t(id)]++;
   }
   order.resize(N);
   size_t numElt = 0;
