@@ -1495,7 +1495,7 @@ bool RagTime5StyleManager::GraphicStyle::read(MWAWInputStreamPtr &input, RagTime
       }
       input->seek(field.m_entry.begin(), librevenge::RVNG_SEEK_SET);
       for (int i=0; i<2; ++i) {
-        static int const(expected[])= {0xb, 0x40};
+        static int const expected[]= {0xb, 0x40};
         auto val=static_cast<int>(input->readULong(2));
         if (val!=expected[i])
           s << "pat" << i << "=" << std::hex << val << std::dec << ",";
@@ -1988,7 +1988,7 @@ bool RagTime5StyleManager::TextStyle::read(RagTime5StructManager::Field const &f
           if (wh==2)
             m_fontName=child.m_string;
           else {
-            static char const *(what[])= {"[full]" /* unsure */, "[##UNDEF]", "", "[style]" /* regular, ...*/, "[from]", "[full2]"};
+            static char const *what[]= {"[full]" /* unsure */, "[##UNDEF]", "", "[style]" /* regular, ...*/, "[from]", "[full2]"};
             s << "font" << what[wh] << "=\"" << child.m_string.cstr() << "\",";
           }
           continue;
@@ -2329,7 +2329,7 @@ std::ostream &operator<<(std::ostream &o, RagTime5StyleManager::TextStyle const
   }
   for (int i=0; i<3; ++i) {
     if (style.m_margins[i]<0) continue;
-    static char const *(wh[])= {"left", "right", "first"};
+    static char const *wh[]= {"left", "right", "first"};
     o << "margins[" << wh[i] << "]=" << style.m_margins[i] << ",";
   }
   for (int i=0; i<3; ++i) {
@@ -2414,7 +2414,7 @@ std::ostream &operator<<(std::ostream &o, RagTime5StyleManager::TextStyle const
 
   for (int i=0; i<4; ++i) {
     if (style.m_letterSpacings[i]<=0&&style.m_letterSpacings[i]>=0) continue;
-    static char const *(wh[])= {"", "[unkn]", "[min]", "[max]"};
+    static char const *wh[]= {"", "[unkn]", "[min]", "[max]"};
     o << "letterSpacing" << wh[i] << "=" << style.m_letterSpacings[i] << ",";
   }
   if (style.m_widthStreching>=0)
