@@ -89,6 +89,8 @@ struct Pattern final : public MWAWGraphicStyle::Pattern {
     }
     m_percent=float(numOnes)/64.f;
   }
+  Pattern(Pattern const &)=default;
+  Pattern &operator=(Pattern const &)=default;
   //! destructor
   ~Pattern() final;
   //! the percentage
@@ -256,9 +258,9 @@ std::ostream &operator<<(std::ostream &o, Zone const &z)
     o << "arrows[end],";
   o << "ids=[";
   for (int i=0; i<5; ++i) {
-    static char const *(wh[])= {"parent", "prev", "next", "child", "linked"};
-    if (z.m_linkZones[i])
-      o <<  wh[i] << "=Z" << z.m_linkZones[i] << ",";
+    if (!z.m_linkZones[i]) continue;
+    static char const *wh[]= {"parent", "prev", "next", "child", "linked"};
+    o <<  wh[i] << "=Z" << z.m_linkZones[i] << ",";
   }
   o << "],";
   if (z.m_sharedWith)
@@ -312,7 +314,7 @@ void State::initDefaultPatterns(int vers)
 {
   if (!m_patternList.empty()) return;
   if (vers <= 2) {
-    static uint16_t const(s_pattern[4*40]) = {
+    static uint16_t const s_pattern[4*40] = {
       0x0, 0x0, 0x0, 0x0, 0x8000, 0x800, 0x8000, 0x800, 0x8800, 0x2200, 0x8800, 0x2200, 0x8822, 0x8822, 0x8822, 0x8822,
       0xaa55, 0xaa55, 0xaa55, 0xaa55, 0xdd77, 0xdd77, 0xdd77, 0xdd77, 0xddff, 0x77ff, 0xddff, 0x77ff, 0xffff, 0xffff, 0xffff, 0xffff,
       0x8888, 0x8888, 0x8888, 0x8888, 0xff00, 0x0, 0xff00, 0x0, 0xaaaa, 0xaaaa, 0xaaaa, 0xaaaa, 0xff00, 0xff00, 0xff00, 0xff00,
@@ -665,7 +667,7 @@ bool RagTimeParser::createZones()
        BuGr : structure with many data of size 0x1a
        Unamed: sometimes structured
      */
-    static char const *(what[])= {
+    static char const *what[]= {
       "rsrcgray", "rsrccolr", "rsrcres_",
       "rsrcBuSl", "rsrcBuGr", "rsrcUnamed"
     };
@@ -967,7 +969,7 @@ bool RagTimeParser::readDataZoneHeader(int id, long endPos)
     bool const isLine=zone.m_type==RagTimeParserInternal::Zone::Line;
     int const numColorsInFile=isLine ? 1 : 2;
     for (int i=0; i<numColorsInFile; ++i) {
-      static char const *(wh[])= {"line", "surf"};
+      static char const *wh[]= {"line", "surf"};
       int col;
       if (vers<2) {
         percentValues[i]=static_cast<int>(input->readLong(1));
@@ -1389,7 +1391,7 @@ bool RagTimeParser::readPictZoneV2(MWAWEntry &entry)
       f << "id2=" << std::hex << input->readULong(4) << std::dec << ",";
       int val;
       for (int i=0; i<14; ++i) {
-        static int const(expected[])= {0,0x1f22,0xffe8,0xff80,0x2c,0x3f,0x2d0,0x2d0,2,0x2d,0x3c,0,0x16,0x9dba};
+        static int const expected[]= {0,0x1f22,0xffe8,0xff80,0x2c,0x3f,0x2d0,0x2d0,2,0x2d,0x3c,0,0x16,0x9dba};
         val=static_cast<int>(input->readULong(2));
         if (val!=expected[i])
           f << "f" << i << "=" << std::hex << val << std::dec << ",";
