@@ -33,6 +33,7 @@
 
 #include <iomanip>
 #include <iostream>
+#include <memory>
 #include <string>
 #include <sstream>
 
@@ -60,10 +61,17 @@ class Exception
 
 struct File {
   //! the constructor
-  File(char const *path) : m_fName(path ? path : ""),
-    m_fInfoCreator(""), m_fInfoType(""), m_fInfoResult(""),
-    m_fileVersion(), m_appliVersion(), m_rsrcMissingMessage(""), m_rsrcResult(""),
-    m_dataResult(), m_printFileName(false)
+  explicit File(char const *path)
+    : m_fName(path ? path : "")
+    , m_fInfoCreator("")
+    , m_fInfoType("")
+    , m_fInfoResult("")
+    , m_fileVersion()
+    , m_appliVersion()
+    , m_rsrcMissingMessage("")
+    , m_rsrcResult("")
+    , m_dataResult()
+    , m_printFileName(false)
   {
     if (m_fName.empty()) {
       std::cerr << "File::File: call without path\n";
@@ -110,8 +118,8 @@ struct File {
     }
     if (info.m_dataResult.size()) {
       o << "------- data fork -------\n";
-      for (size_t i = 0; i < info.m_dataResult.size(); i++)
-        o << "\t\t=>" << info.m_dataResult[i] << "\n";
+      for (auto const &res : info.m_dataResult)
+        o << "\t\t=>" << res << "\n";
     }
     return o;
   }
@@ -191,11 +199,10 @@ bool File::readFileInformation()
     return false;
 
   XAttr xattr(m_fName.c_str());
-  libmwaw_tools::InputStream *input = xattr.getStream("com.apple.FinderInfo");
+  std::unique_ptr<InputStream> input{xattr.getStream("com.apple.FinderInfo")};
   if (!input) return false;
 
   if (input->length() < 8) {
-    delete input;
     return false;
   }
 
@@ -212,7 +219,6 @@ bool File::readFileInformation()
     if (c==0) break;
     m_fInfoCreator+= c;
   }
-  delete input;
 
   if (m_fInfoCreator=="" || m_fInfoType=="")
     return true;
@@ -220,7 +226,9 @@ bool File::readFileInformation()
     checkFInfoType("SPUB", "PublishIt") || checkFInfoType("PublishIt");
   }
   else if (m_fInfoCreator=="AB65") {
-    checkFInfoType("AD65", "Pagemaker6.5") || checkFInfoType("Pagemaker6.5");
+    checkFInfoType("AD65", "Pagemaker6.5") ||
+    checkFInfoType("AT65", "Pagemaker6.5[template]") ||
+    checkFInfoType("Pagemaker6.5");
   }
   else if (m_fInfoCreator=="ACTA") {
     checkFInfoType("OTLN", "Acta") || checkFInfoType("otln", "Acta") || checkFInfoType("Acta");
@@ -245,8 +253,11 @@ bool File::readFileInformation()
     checkFInfoType("TEXT","eWorld") || checkFInfoType("ttro","eWorld[readOnly]") ||
     checkFInfoType("eWorld");
   }
+  else if (m_fInfoCreator=="ARTX") {
+    checkFInfoType("RIFF","Corel Painter X") || checkFInfoType("Corel Painter X");
+  }
   else if (m_fInfoCreator=="BOBO") {
-    checkFInfoType("CWDB","ClarisWorks/AppleWorks 1.0[Database]")||
+    checkFInfoType("CWDB","ClarisWorks/AppleWorks[Database]")||
     checkFInfoType("CWD2","ClarisWorks/AppleWorks 2.0-3.0[Database]")||
     checkFInfoType("sWDB","ClarisWorks/AppleWorks 2.0-3.0[Database]")||
     checkFInfoType("CWGR","ClarisWorks/AppleWorks[Draw]")||
@@ -304,6 +315,15 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="FS03") {
     checkFInfoType("WRT+","WriterPlus") || checkFInfoType("WriterPlus");
   }
+  else if (m_fInfoCreator=="FSDA") {
+    checkFInfoType("RIFF","Dabbler 1") || checkFInfoType("Dabbler 1");
+  }
+  else if (m_fInfoCreator=="FSPS") {
+    checkFInfoType("RIFF","Painter 1") || checkFInfoType("FSPP","Painter[texture]") || checkFInfoType("Painter 1");
+  }
+  else if (m_fInfoCreator=="FSX3") {
+    checkFInfoType("RIFF","Painter 3-6") || checkFInfoType("FSFS","Painter 3-6[movie]") || checkFInfoType("Painter 3-6");
+  }
   else if (m_fInfoCreator=="Fram") {
     checkFInfoType("FASL","FrameMaker") || checkFInfoType("MIF2","FrameMaker MIF2.0") ||
     checkFInfoType("MIF3","FrameMaker MIF3.0") || checkFInfoType("MIF ","FrameMaker MIF") ||
@@ -426,6 +446,9 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="PIXR") {
     checkFInfoType("PX01","Pixel Paint") || checkFInfoType("Pixel Paint");
   }
+  else if (m_fInfoCreator=="PLAN") {
+    checkFInfoType("MPBN","MultiPlan") || checkFInfoType("MultiPlan");
+  }
   else if (m_fInfoCreator=="PPNT") {
     checkFInfoType("SLDS","Microsoft PowerPoint") || checkFInfoType("Microsoft PowerPoint v1/2");
   }
@@ -476,6 +499,16 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="StAV") {
     checkFInfoType("APPL", "Style[auto]") || checkFInfoType("Style");
   }
+  else if (m_fInfoCreator=="SVsc") {
+    checkFInfoType("SVsc", "StarCalc 3.0") || checkFInfoType("StarCalc 3.0");
+  }
+  else if (m_fInfoCreator=="SVsd") {
+    checkFInfoType("SVsd", "StarDraw 3.0") || checkFInfoType("StarDraw 3.0");
+  }
+  else if (m_fInfoCreator==std::string("SW/")+char(0xa9)) {
+    std::string type1=std::string("SW/")+char(0xa9);
+    checkFInfoType(type1.c_str(), "StarWriter 3.0") ||  checkFInfoType("StarWriter 3.0");
+  }
   else if (m_fInfoCreator=="TBB5") {
     checkFInfoType("TEXT","Tex-Edit") || checkFInfoType("ttro","Tex-Edit[readOnly]") ||
     checkFInfoType("Tex-Edit");
@@ -503,7 +536,14 @@ bool File::readFileInformation()
     checkFInfoType("Microsoft Excel");
   }
   else if (m_fInfoCreator=="XPR3") {
-    checkFInfoType("XDOC","QuarkXPress") || checkFInfoType("QuarkXPress");
+    checkFInfoType("XDOC","QuarkXPress 3-4") ||
+    checkFInfoType("XTMP","QuarkXPress 3-4[template]") ||
+    checkFInfoType("XBOK","QuarkXPress 4[book]") ||
+    checkFInfoType("XLIB","QuarkXPress 4[library]") ||
+    checkFInfoType("QuarkXPress 3-4");
+  }
+  else if (m_fInfoCreator=="XPRS") {
+    checkFInfoType("XDOC","QuarkXPress 1-2") || checkFInfoType("QuarkXPress 1-2");
   }
   else if (m_fInfoCreator=="ZEBR") {
     checkFInfoType("ZWRT","GreatWorks") || checkFInfoType("ZTRM","GreatWorks[comm]") ||
@@ -543,14 +583,12 @@ bool File::readFileInformation()
       /* a little complex can be Classic MacOS SimpleText/TeachText or
       a << normal >> text file */
       XAttr rsrcAttr(m_fName.c_str());
-      libmwaw_tools::InputStream *rsrcStream =
-        rsrcAttr.getStream("com.apple.ResourceFork");
+      std::unique_ptr<InputStream> rsrcStream{rsrcAttr.getStream("com.apple.ResourceFork")};
       bool ok = false;
       if (rsrcStream && rsrcStream->length()) {
         libmwaw_tools::RSRC rsrcManager(*rsrcStream);
         ok = rsrcManager.hasEntry("styl", 128);
       }
-      if (rsrcStream) delete rsrcStream;
       if (ok) checkFInfoType("TEXT","TeachText/SimpleText");
       else checkFInfoType("TEXT","Basic text");
     }
@@ -583,8 +621,7 @@ bool File::readDataInformation()
     return true;
   input.seek(0, InputStream::SK_SET);
   int val[5];
-  for (int i = 0; i < 5; i++)
-    val[i] = int(input.readU16());
+  for (auto &v : val) v = int(input.readU16());
   // ----------- clearly discriminant ------------------
   if (val[2] == 0x424F && val[3] == 0x424F && (val[0]>>8) < 8) {
     m_dataResult.push_back("ClarisWorks/AppleWorks");
@@ -754,9 +791,9 @@ bool File::readDataInformation()
   // ----------- less discriminant ------------------
   if (val[0]==0xd0cf && val[1]==0x11e0 && val[2]==0xa1b1 && val[3]==0x1ae1) {
     libmwaw_tools::OLE ole(input);
-    for (int step=0; step < 2; step++) {
-      std::string res=step==0 ? ole.getCLSIDType() : ole.getCompObjType();
-      if (!res.length())
+    for (int step=0; step < 3; step++) {
+      std::string res=step==0 ? ole.getClipName() : step==1 ? ole.getCLSIDType() : ole.getCompObjType();
+      if (res.empty())
         continue;
       m_dataResult.push_back(res);
       return true;
@@ -862,6 +899,10 @@ bool File::readDataInformation()
     m_dataResult.push_back("Microsoft PowerPoint Windows");
     return true;
   }
+  if (val[0]==0x11ab && val[1]==0x0 && val[2]==0x13e8 && val[3]==0) {
+    m_dataResult.push_back("Microsoft Multiplan Mac");
+    return true;
+  }
   if (val[0] == 3 || val[0] == 6) {
     int numParaPos = val[0] == 3 ? 2 : 1;
     if (val[numParaPos] < 0x1000 && val[numParaPos+1] < 0x100 && val[numParaPos+2] < 0x100)
@@ -919,7 +960,7 @@ bool File::readDataInformation()
       bool ok=true;
       int numSlash=0;
       for (int i=0; i<sSz; ++i) {
-        char c=char(input.readU8());
+        auto c=char(input.readU8());
         if (c>='0' && c<='9')
           continue;
         if (c=='/')
@@ -935,8 +976,7 @@ bool File::readDataInformation()
   }
   input.seek(-4, InputStream::SK_END);
   int lVal[2];
-  for (int i = 0; i < 2; i++)
-    lVal[i] = int(input.readU16());
+  for (auto &v : lVal) v = int(input.readU16());
   if (lVal[0] == 0x4657 && lVal[1]==0x5254)
     m_dataResult.push_back("FullWrite 2.0");
   else if (lVal[0] == 0x4E4C && lVal[1]==0x544F)
@@ -948,8 +988,8 @@ bool File::readDataInformation()
     long eof = input.length();
     bool ok = true;
     for (int i = 0; i < 2; i++) {
-      long pos = long(input.readU32());
-      long sz = long(input.read32());
+      auto pos = long(input.readU32());
+      auto sz = long(input.read32());
       if (sz <= 0 || pos+sz > eof) {
         ok = false;
         break;
@@ -962,8 +1002,8 @@ bool File::readDataInformation()
   if (m_dataResult.size()==0) {
     std::stringstream s;
     s << "Unknown: " << std::hex << std::setfill('0');
-    for (int i = 0; i < 5; i++)
-      s << std::setw(4) << val[i] << " ";
+    for (auto v : val)
+      s << std::setw(4) << v << " ";
     m_dataResult.push_back(s.str());
   }
 #endif
@@ -976,11 +1016,10 @@ bool File::readRSRCInformation()
     return false;
 
   XAttr xattr(m_fName.c_str());
-  libmwaw_tools::InputStream *rsrcStream = xattr.getStream("com.apple.ResourceFork");
+  std::unique_ptr<libmwaw_tools::InputStream> rsrcStream{xattr.getStream("com.apple.ResourceFork")};
   if (!rsrcStream) return false;
 
   if (!rsrcStream->length()) {
-    delete rsrcStream;
     return true;
   }
   libmwaw_tools::RSRC rsrcManager(*rsrcStream);
@@ -989,23 +1028,22 @@ bool File::readRSRCInformation()
 #  endif
   m_rsrcResult = rsrcManager.getString(-16396); // the application missing name
   m_rsrcMissingMessage = rsrcManager.getString(-16397);
-  std::vector<RSRC::Version> listVersion = rsrcManager.getVersionList();
-  for (size_t i=0; i < listVersion.size(); i++) {
-    switch (listVersion[i].m_id) {
+  auto listVersion = rsrcManager.getVersionList();
+  for (auto const &vers : listVersion) {
+    switch (vers.m_id) {
     case 1:
-      m_fileVersion = listVersion[i];
+      m_fileVersion = vers;
       break;
     case 2:
-      if (!m_appliVersion.ok()) m_appliVersion = listVersion[i];
+      if (!m_appliVersion.ok()) m_appliVersion = vers;
       break;
     case 2002:
-      m_appliVersion = listVersion[i];
+      m_appliVersion = vers;
       break;
     default:
       break;
     }
   }
-  delete rsrcStream;
   return true;
 }
 
@@ -1097,14 +1135,13 @@ int main(int argc, char *const argv[])
     usage(argv[0]);
     return -1;
   }
-  libmwaw_tools::File *file = 0;
+  std::unique_ptr<libmwaw_tools::File> file;
   try {
-    file=new libmwaw_tools::File(argv[optind]);
+    file.reset(new libmwaw_tools::File(argv[optind]));
     file->readFileInformation();
   }
   catch (...) {
     std::cerr << argv[0] << ": can not open file " << argv[optind] << "\n";
-    if (file) delete file;
     return -1;
   }
   if (!file)
@@ -1125,7 +1162,6 @@ int main(int argc, char *const argv[])
     std::cout << *file;
   else if (file->canPrintResult(verbose))
     file->printResult(std::cout, verbose);
-  delete file;
   return 0;
 }
 // vim: set filetype=cpp tabstop=2 shiftwidth=2 cindent autoindent smartindent noexpandtab:
